@@ -1,10 +1,11 @@
-
 _registry = {}
 
 
 def register(app_label, logic_class):
     if app_label in _registry:
-        raise AttributeError("The \"%s\" app is already registerd by simple_perms" % app_label)
+        raise AttributeError(
+            f'The "{app_label}" app is already registerd by simple_perms'
+        )
     _registry[app_label] = logic_class()
 
 
